@@ -1,9 +1,9 @@
 #!/usr/bin/env python3
 # -*- encoding: utf-8
 # SPDX-License-Identifier: MIT
-# Copyright (c) 2021 - 2021, Scott.McCallum@HQ.UrbaneInter.net
+# Copyright (c) 2021 - 2022, Scott.McCallum@HQ.UrbaneINTER.NET
 
-__banner__ = r""" ( This string is also the module initilizer program.
+__banner__ = r""" (
 
      _       _____    ____    _   _   _______   _____     ____    _
   /\| |/\   / ____|  / __ \  | \ | | |__   __| |  __ \   / __ \  | |
@@ -20,6 +20,8 @@ __banner__ = r""" ( This string is also the module initilizer program.
 
 
 
+
+
 """  # __banner__
 
 
@@ -57,8 +59,16 @@ class LIB:  # { Control Flow : words }
     def word_EXIT__R(e, t, c):
         c.EXIT = True
 
+    @staticmethod  ### STOP ###
+    def word_STOP__R(e, t, c):
+        c.EXIT = True
+        p = c.parent
+        while p:
+            p.EXIT = True
+            p = p.parent
+
     @staticmethod  ### V ###
-    def word_V__R_x(e, t, c):
+    def word_V__2R_x(e, t, c):
         call = c
         while call:
             for index in range(-1, (len(call.stack) * -1) - 1, -1):
@@ -237,7 +247,6 @@ class LIB:  # { Control Flow : words }
 
         if struct[0] == 1:
             while True:
-                print(t.stack, struct[1])
                 e.execute_tokens(e, t, c, struct[1])
                 b = t.stack.pop()
                 if b:
@@ -245,7 +254,6 @@ class LIB:  # { Control Flow : words }
 
         if struct[0] == 2:
             while True:
-                print(t.stack, struct[1], struct[2])
                 e.execute_tokens(e, t, c, struct[1])
                 b = t.stack.pop()
                 if not b:
@@ -278,6 +286,8 @@ class LIB:  # { Control Flow : words }
 
         t.state = block["r"]
 
+
+
     @staticmethod  ### IF ###
     def word_IF__R(e, t, c, b):
         c.stack.append({"?": "IF", "b": b, 0: [], 1: [], "r": t.state})
