@@ -1,9 +1,9 @@
 #!/usr/bin/env python3
 # -*- encoding: utf-8
 # SPDX-License-Identifier: MIT
-# Copyright (c) 2021 - 2021, Scott.McCallum@HQ.UrbaneInter.net
+# Copyright (c) 2021 - 2022, Scott.McCallum@HQ.UrbaneINTER.NET
 
-__banner__ = r""" ( This string is also the module initilizer program.
+__banner__ = r""" (
 
      _       _____   _______               _____   _  __
   /\| |/\   / ____| |__   __|     /\      / ____| | |/ /
@@ -20,6 +20,8 @@ __banner__ = r""" ( This string is also the module initilizer program.
 
 
 
+
+
 """  # __banner__
 
 
@@ -71,9 +73,9 @@ class LIB:  # { DATA Stack Manipulation : words }
         return (x1, x2, x1, x2)
 
     @staticmethod  ### NIP ###
-    def word_NIP__R_n2(e, t, c, n1, n2):
+    def word_NIP__R_x2(e, t, c, x1, x2):
         """"""
-        return (n2,)
+        return (x2,)
 
     @staticmethod  ### ROT ###
     def word_ROT__R_x2_x3_x1(e, t, c, x1, x2, x3):
@@ -91,7 +93,7 @@ class LIB:  # { DATA Stack Manipulation : words }
         return None
 
     @staticmethod  ### DROP-ALL ###
-    def word_DROP_minus_ALL__R(e, t, c):
+    def word_DROP_m_ALL__R(e, t, c):
         # "T{ 1 2 DROP:ALL -> }T
         t.stack = []
 
@@ -116,6 +118,6 @@ class LIB:  # { DATA Stack Manipulation : words }
         return (x3, x4, x1, x2)
 
     @staticmethod  ### TUCK ###
-    def word_TUCK(e, t, c, n1, n2):
+    def word_TUCK(e, t, c, x1, x2):
         """"""
-        return (n2, n1, n2)
+        return (x2, x1, x2)
