@@ -16,7 +16,7 @@ __banner__ = r""" (
                     |______|
 )
 
-
+See footer for (c)
 
 
 
@@ -29,39 +29,49 @@ class TestFORTH:
 
     def test_0000(self):
         r"""
+        ```
         1 2 3
+        : hello 'World ;
         """
-        e = FORTH.Engine(self.test_0000.__doc__, **self.options)
+        e = FORTH.Engine(run=self.test_0000.__doc__, **self.options)
         assert e.root.stack == [1, 2, 3]
         assert e.root.memory == {}
+        assert e.root.test["f"] == 0
 
     def test_0001(self):
         r"""
+        ```
         'Hello 'World
         """
         e = FORTH.Engine(self.test_0001.__doc__, **self.options)
         assert e.root.stack == ["Hello", "World"]
         assert e.root.memory == {}
+        assert e.root.test["f"] == 0
 
     def test_0002(self):
         r"""
+        ```
         123 456 !
         """
         e = FORTH.Engine(self.test_0002.__doc__, **self.options)
         assert e.root.stack == []
         assert e.root.memory == {456: 123}
+        assert e.root.test["f"] == 0
 
     def test_0003(self):
         r"""
+        ```
         123 'FOO_1 !
         'Baz 'FOO_2 !
         """
         e = FORTH.Engine(self.test_0003.__doc__, **self.options)
         assert e.root.stack == []
         assert e.root.memory == {"FOO_1": 123, "FOO_2": "Baz"}
+        assert e.root.test["f"] == 0
 
     def test_1000(self):
         r"""
+        ```
         T{ 'Hello 'World DROP -> ("Hello") }T
         """
         e = FORTH.Engine(self.test_1000.__doc__, **self.options)
@@ -73,6 +83,8 @@ class TestFORTH:
 
     BASIC_ASSUMPTIONS = r"""
 
+```
+
 T{ -> }T               \ START WITH CLEAN SLATE
 ( TEST IF ANY BITS ARE SET; ANSWER IN BASE 1 )
 T{ : BITSSET? IF 0 0 ELSE 0 THEN ; -> }T
@@ -88,6 +100,8 @@ T{ -1 BITSSET? -> 0 0 }T
 
     BOOLEANS_INVERT = r"""
 
+```
+
 T{ 0 0 AND -> 0 }T
 T{ 0 1 AND -> 0 }T
 T{ 1 0 AND -> 0 }T
@@ -125,6 +139,8 @@ T{ 1S 1S XOR -> 0S }T
 
     LSHIFT_RSHIFT = r"""
 
+```
+
 0    CONSTANT 0S
 0 INVERT CONSTANT 1S
 1S 1 RSHIFT INVERT CONSTANT MSB
@@ -172,6 +188,8 @@ T{ MSB 1 RSHIFT 2* -> MSB }T
 
     COMPARISONS = r"""
 
+```
+
 0    CONSTANT 0S
 0 INVERT CONSTANT 1S
 1S 1 RSHIFT INVERT CONSTANT MSB
@@ -255,6 +273,8 @@ T{ 1 -1 MAX -> 1 }T
 
     STACK_OPS = r"""
 
+```
+
 T{ 1 2 2DROP -> }T
 T{ 1 2 2DUP -> 1 2 1 2 }T
 T{ 1 2 3 4 2OVER -> 1 2 3 4 1 2 }T
@@ -280,6 +300,8 @@ T{ 1 2 SWAP -> 2 1 }T
 
     RETURN_STACK = r"""
 
+```
+
 0 CONSTANT 0S
 0 INVERT CONSTANT 1S
 
@@ -299,6 +321,8 @@ T{ 1S GR1 -> 1S }T   ( RETURN STACK HOLDS CELLS )
 
     ADD_SUBTRACT = r"""
 
+```
+
 T{ 0 5 + -> 5 }T
 T{ 5 0 + -> 5 }T
 T{ 0 -5 + -> -5 }T
@@ -350,6 +374,8 @@ T{ -1 ABS -> 1 }T
 
     MULTIPLY = r"""
 
+```
+
 # T{ 0 S>D -> 0 0 }T
 # T{ 1 S>D -> 1 0 }T
 # T{ 2 S>D -> 2 0 }T
@@ -412,6 +438,8 @@ T{ -3 -3 * -> 9 }T
 
     HERE = r"""
 
+```
+
 0 CONSTANT 0S
 0 INVERT CONSTANT 1S
 
@@ -504,6 +532,8 @@ T{ 123 456 A-ADDR CELL+ 2!  A-ADDR CELL+ 2@ -> 123 456 }T
 
     COMPILE = r"""
 
+```
+
 T{ : GT1 123 ; -> }T
 T{ ' GT1 EXECUTE -> 123 }T
 T{ : GT2 ['] GT1 ; IMMEDIATE -> }T
@@ -542,6 +572,8 @@ T{ GT7 -> 345 }T
 
     IF_BEGIN_WHILE_RECURSE = r"""
 
+```
+
 T{ : GI1 IF 123 THEN ; -> }T
 T{ : GI2 IF 123 ELSE 234 THEN ; -> }T
 T{ 0 GI1 -> }T
@@ -589,6 +621,8 @@ T{ 6 GI4 -> 6 7 }T
 
     DO_LOOP = r"""
 
+```
+
 T{ : GD1 DO I LOOP ; -> }T
 T{ 4 1 GD1 -> 1 2 3 }T
 T{ 2 -1 GD1 -> -1 0 1 }T
@@ -628,6 +662,8 @@ T{ 6 GD5 -> 234 }T
 
     DEFINING_WORDS = r"""
 
+```
+
 T{ 123 CONSTANT X123 -> }T
 T{ X123 -> 123 }T
 T{ : EQU CONSTANT ; -> }T
@@ -676,6 +712,8 @@ T{ CR1 @ -> 1 }T
 
     EVALUATE = r"""
 
+```
+
 ( TODO
 
 : GE1 S" 123" ; IMMEDIATE
@@ -703,6 +741,8 @@ T{ GE7 -> 124 }T
 
     SOURCE = r"""
 
+```
+
 ( TODO
 
 : GS1 S" SOURCE" 2DUP EVALUATE
@@ -739,6 +779,8 @@ T{ GS4 123 456
 
     FILL_MOVE = r"""
 
+```
+
 CREATE FBUF 00 C, 00 C, 00 C,
 CREATE SBUF 12 C, 34 C, 56 C,
 : SEEBUF FBUF C@  FBUF CHAR+ C@  FBUF CHAR+ CHAR+ C@ ;
